@@ -14,14 +14,11 @@
 
 
 #include "k3babstractwriter.h"
-
 #include "k3bcore.h"
 #include "k3bdevicemanager.h"
 #include "k3bdevicehandler.h"
 #include "k3bglobalsettings.h"
-
-#include <klocale.h>
-#include <kglobal.h>
+#include "k3b_i18n.h"
 
 
 
@@ -92,4 +89,4 @@ void K3b::AbstractWriter::slotEjectWhileCancellationFinished( bool success )
 }
 
 
-#include "k3babstractwriter.moc"
+
