@@ -18,7 +18,7 @@
 ** Foundation and appearing in the file LICENSE.LGPL included in the
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** will be met: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain
 ** additional rights. These rights are described in the Nokia Qt LGPL
@@ -31,7 +31,7 @@
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** If you are unsure which license is appropriate for your use, please
 ** contact the sales department at qt-sales@nokia.com.
@@ -45,11 +45,11 @@
 #include "private/qfsfileengine_p.h"
 #include <qdebug.h>
 
-#include "qfile.h"
-#include "qdir.h"
+#include "QtCore/QFile"
+#include "QtCore/QDir"
 #include "qtemporaryfile.h"
 #ifndef QT_NO_REGEXP
-# include "qregexp.h"
+# include "QtCore/QRegExp"
 #endif
 #include "private/qmutexpool_p.h"
 #include "qvarlengtharray.h"
@@ -1055,7 +1055,7 @@ bool QFSFileEngine::mkdir(const QString &name, bool createParentDirectories) con
     QString dirName = name;
     if (createParentDirectories) {
         dirName = QDir::toNativeSeparators(QDir::cleanPath(dirName));
-        // We spefically search for / so \ would break it..
+        // We specifically search for / so \ would break it..
         int oldslash = -1;
         if (dirName.startsWith(QLatin1String("\\\\"))) {
             // Don't try to create the root path of a UNC path;
@@ -1731,7 +1731,7 @@ QAbstractFileEngine::FileFlags QFSFileEnginePrivate::getPermissions() const
            {
 	//### what to do with permissions if we don't use ntfs or are not on a NT system
 	// for now just add all permissions and what about exe missions ??
-	// also qt_ntfs_permission_lookup is now not set by defualt ... should it ?
+	// also qt_ntfs_permission_lookup is now not set by default ... should it ?
     	ret |= QAbstractFileEngine::ReadOtherPerm | QAbstractFileEngine::ReadGroupPerm
 	    | QAbstractFileEngine::ReadOwnerPerm | QAbstractFileEngine::ReadUserPerm
 	    | QAbstractFileEngine::WriteUserPerm | QAbstractFileEngine::WriteOwnerPerm
