@@ -19,7 +19,7 @@
 #include "k3btrm.h"
 #include "musicbrainz/mb_c.h"
 
-#include <KIOCore/KProtocolManager>
+#include <KProtocolManager>
 #include <QDebug>
 #include <QUrl>
 
